FileDialog

Struct FileDialog 

pub struct FileDialog<'a> { /* private fields */ }
Builds and shows file dialogs.

Implementations

Source

impl<'a> FileDialog<'a>

pub fn new() -> Self

Creates a file dialog builder.

pub fn set_title(self, title: &'a str) -> Self

Sets the window title for the dialog.

pub fn set_filename(self, filename: &'a str) -> Self

Sets the default value of the filename text field in the dialog. For open dialogs of macOS and zenity, this is a no-op because there’s no such text field on the dialog.

pub fn reset_filename(self) -> Self

Resets the default value of the filename field in the dialog.

pub fn set_location<P: AsRef<Path> + ?Sized>(self, path: &'a P) -> Self

Sets the default location that the dialog shows at open.

pub fn reset_location(self) -> Self

Resets the default location that the dialog shows at open. Without a default location set, the dialog will probably use the current working directory as default location.

pub fn add_filter(self, description: &'a str, extensions: &'a [&'a str]) -> Self

Adds a file type filter. The filter must contains at least one extension, otherwise this method will panic. For dialogs that open directories, this is a no-op.

pub fn remove_all_filters(self) -> Self

Removes all file type filters.

pub fn set_owner<W: HasWindowHandle>(self, window: Option<&W>) -> Self

Sets the owner of the dialog. On Unix and GNU/Linux, this is a no-op.

pub unsafe fn set_owner_handle(self, handle: Option<RawWindowHandle>) -> Self

Sets the owner of the dialog by raw handle. On Unix and GNU/Linux, this is a no-op.

Safety

It’s the caller’s responsibility that ensuring the handle is valid.

pub fn reset_owner(self) -> Self

Resets the owner of the dialog to nothing.

pub fn show_open_single_file(self) -> Result<Option<PathBuf>>

Shows a dialog that let users to open one file.

pub fn show_open_multiple_file(self) -> Result<Vec<PathBuf>>

Shows a dialog that let users to open multiple files.

pub fn show_open_single_dir(self) -> Result<Option<PathBuf>>

Shows a dialog that let users to open one directory.

pub fn show_save_single_file(self) -> Result<Option<PathBuf>>

Shows a dialog that let users to save one file.