pub struct FileDialog<'a> { /* private fields */ }Expand description
Builds and shows file dialogs.
Implementations
Sourceimpl<'a> FileDialog<'a>
impl<'a> FileDialog<'a>
Sourcepub fn set_filename(self, filename: &'a str) -> Self
pub fn set_filename(self, filename: &'a str) -> Self
Sets the default value of the filename text field in the dialog. For open dialogs of macOS and zenity, this is a no-op because there’s no such text field on the dialog.
Sourcepub fn reset_filename(self) -> Self
pub fn reset_filename(self) -> Self
Resets the default value of the filename field in the dialog.
Sourcepub fn set_location<P: AsRef<Path> + ?Sized>(self, path: &'a P) -> Self
pub fn set_location<P: AsRef<Path> + ?Sized>(self, path: &'a P) -> Self
Sets the default location that the dialog shows at open.
Sourcepub fn reset_location(self) -> Self
pub fn reset_location(self) -> Self
Resets the default location that the dialog shows at open. Without a default location set, the dialog will probably use the current working directory as default location.
Sourcepub fn add_filter(self, description: &'a str, extensions: &'a [&'a str]) -> Self
pub fn add_filter(self, description: &'a str, extensions: &'a [&'a str]) -> Self
Adds a file type filter. The filter must contains at least one extension, otherwise this method will panic. For dialogs that open directories, this is a no-op.
Sourcepub fn remove_all_filters(self) -> Self
pub fn remove_all_filters(self) -> Self
Removes all file type filters.
Sourcepub fn set_owner<W: HasWindowHandle>(self, window: Option<&W>) -> Self
pub fn set_owner<W: HasWindowHandle>(self, window: Option<&W>) -> Self
Sets the owner of the dialog. On Unix and GNU/Linux, this is a no-op.
Sourcepub unsafe fn set_owner_handle(self, handle: Option<RawWindowHandle>) -> Self
pub unsafe fn set_owner_handle(self, handle: Option<RawWindowHandle>) -> Self
Sets the owner of the dialog by raw handle. On Unix and GNU/Linux, this is a no-op.
Safety
It’s the caller’s responsibility that ensuring the handle is valid.
Sourcepub fn reset_owner(self) -> Self
pub fn reset_owner(self) -> Self
Resets the owner of the dialog to nothing.
Sourcepub fn show_open_single_file(self) -> Result<Option<PathBuf>>
pub fn show_open_single_file(self) -> Result<Option<PathBuf>>
Shows a dialog that let users to open one file.
Sourcepub fn show_open_multiple_file(self) -> Result<Vec<PathBuf>>
pub fn show_open_multiple_file(self) -> Result<Vec<PathBuf>>
Shows a dialog that let users to open multiple files.
Sourcepub fn show_open_single_dir(self) -> Result<Option<PathBuf>>
pub fn show_open_single_dir(self) -> Result<Option<PathBuf>>
Shows a dialog that let users to open one directory.
Sourcepub fn show_save_single_file(self) -> Result<Option<PathBuf>>
pub fn show_save_single_file(self) -> Result<Option<PathBuf>>
Shows a dialog that let users to save one file.